window.Gleam.initSearch([{"doc":"glint","title":"glint","content":"# glint\n\n[![Hex Package](https://img.shields.io/hexpm/v/glint?color=ffaff3&amp;label=%F0%9F%93%A6)](https://hex.pm/packages/glint)\n[![Hex.pm](https://img.shields.io/hexpm/dt/glint?color=ffaff3)](https://hex.pm/packages/glint)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3?label=%F0%9F%93%9A)](https://hexdocs.pm/glint/)\n[![GitHub Workflow Status](https://img.shields.io/github/workflow/status/tanklesxl/glint/main)](https://github.com/tanklesxl/glint/actions)\n\nGleam command-line argument parsing with flags and automated help text generation.\n\n## Installation\n\nTo install from hex:\n\n```sh\ngleam add glint\n```\n\n## Usage\n\nGlint has 3 main concepts (see below for more details): glint itself, commands and flags.\n\nThe general workflow involves\n\n1. creating a new glint instance with `glint.new`\n1. configuring it\n1. creating commands with `glint.command`\n   - attach flags with `glint.flag`\n   - set named args with `glint.named_arg`\n   - set unnamed args with `glint.unnamed_args`\n1. attach the commands to glint with `glint.add`\n1. run your glint app with `glint.run` or `glint.run_and_handle`\n\n### Help text\n\nGlint automatically generates help text for your commands and flags. Help text is both automatically formatted and wrapped. You can attach help text to your commands and flags with the functions described below.\n\n_**Note**_:Help text is generated and printed whenever a glint command is called with the built-in flag `--help`. It is also printed after the error text when any errors are encountered due to invalid flags or arguments.\n\nHelp text descriptions can be attached to all of glint&#39;s components:\n\n- attach global help text with `glint.global_help`\n- attach comand help text with `glint.command_help`\n- attach flag help text with `glint.flag_help`\n- attach help text to a non-initialized command with `glint.path_help`\n\n#### Help text formatting\n\nIt is not uncommon for developers to want to format long text strings in such a way that it is easier to read in a code editor. Glint accounts for this be being sensitive to multiple line breaks in a help text string. This means that text like the following:\n\n```\nA very very very very very very very long help text\nstring that is too long to fit on one line.\n\nHere is something that gets its own line.\n\n\nAnd here is something that gets its own paragraph.\n```\n\nWill be formatted as follows:\n\n```\nA very very very very very very very long help text\nstring that is too long to fit on one line.\nHere is something that gets its own line.\n\nAnd here is something that gets its own paragraph.\n```\n\n#### Help text wrapping\n\nIn addition to newline formatting, glint also handles wrapping helptext so that it fits within the configured terminal width. This means that if you have a long help text string it will be adjusted to fit on additional lines if it is too long to fit on one line. Spacing is also added to keep descriptions aligned with each other.\n\nThere are functions that you can use to tweak glints default wrapping behaviour, but the defaults should be sufficient for the majority of use cases.\n\n### Mini Example\n\nYou can import `glint` as a dependency and use it to build command-line applications like the following simplified version of the [the hello world example](./test/examples/hello.gleam).\n\n```gleam\nimport gleam/io\nimport gleam/list\nimport gleam/result\nimport gleam/string.{uppercase}\nimport glint\nimport argv\n\n// this function returns the builder for the caps flag\nfn caps_flag() -&gt; glint.Flag(Bool) {\n  // create a new boolean flag with key &quot;caps&quot;\n  // this flag will be called as --caps=true (or simply --caps as glint handles boolean flags in a bit of a special manner) from the command line\n  glint.bool_flag(&quot;caps&quot;)\n  // set the flag default value to False\n  |&gt; glint.flag_default(False)\n  //  set the flag help text\n  |&gt; glint.flag_help(&quot;Capitalize the hello message&quot;)\n}\n\n/// the glint command that will be executed\n///\nfn hello() -&gt; glint.Command(Nil) {\n  // set the help text for the hello command\n  use &lt;- glint.command_help(&quot;Prints Hello, &lt;NAME&gt;!&quot;)\n  // register the caps flag with the command\n  // the `caps` variable there is a type-safe getter for the flag value\n  use caps &lt;- glint.flag(caps_flag())\n  // start the body of the command\n  // this is what will be executed when the command is called\n  use _, args, flags &lt;- glint.command()\n  // we can assert here because the caps flag has a default\n  // and will therefore always have a value assigned to it\n  let assert Ok(caps) = caps(flags)\n  // this is where the business logic of our command starts\n  let name = case args {\n        [] -&gt; &quot;Joe&quot;\n        [name,..] -&gt; name\n  }\n  let msg = &quot;Hello, &quot; &lt;&gt; name &lt;&gt; &quot;!&quot;\n  case caps {\n    True -&gt; uppercase(msg)\n    False -&gt; msg\n  }\n  |&gt; io.println\n}\n\npub fn main() {\n  // create a new glint instance\n  glint.new()\n  // with an app name of &quot;hello&quot;, this is used when printing help text\n  |&gt; glint.with_name(&quot;hello&quot;)\n  // with pretty help enabled, using the built-in colours\n  |&gt; glint.pretty_help(glint.default_pretty_help())\n  // with a root command that executes the `hello` function\n  |&gt; glint.add(at: [], do: hello())\n  // execute given arguments from stdin\n  |&gt; glint.run(argv.load().arguments)\n}\n```\n\n## Glint at-a-glance\n\n### Glint core: `glint.Glint(a)`\n\n`glint` is conceptually quite small, your general flow will be:\n\n- create a new glint instance with `glint.new`.\n- configure glint with functions like `glint.with_pretty_help`.\n- add commands with `glint.add`.\n- run your cli with `glint.run`, run with a function to handle command output with `glint.run_and_handle`.\n\n### Glint commands: `glint.Command(a)`\n\n_Note_: Glint commands are most easily set up by chaining functions with `use`. (See the above example)\n\n- Create a new command with `glint.command`.\n- Set the command description with `glint.command_help`.\n- Add a flag to a command with `glint.flag`.\n- Create a named argumend with `glint.named_arg`.\n- Set the expectation for unnamed args with `glint.unnamed_args`.\n\n### Glint flags: `glint.Flag(a)`\n\nGlint flags are a type-safe way to provide options to your commands.\n\n- Create a new flag with a typed flag constructor function:\n\n  - `glint.int_flag`: `glint.Flag(Int)`\n  - `glint.ints_flag`: `glint.Flag(List(Int))`\n  - `glint.float_flag`: `glint.Flag(Float)`\n  - `glint.floats_flag`: `glint.Flag(List(Floats))`\n  - `glint.string_flag`: `glint.Flag(String)`\n  - `glint.strings_flag`: `glint.Flag(List(String))`\n  - `glint.bool_flag`: `glint.Flag(Bool)`\n\n- Set the flag description with `glint.flag_help`\n- Set the flag default value with `glint.flag_default`, **note**: it is safe to use `let assert` when fetching values for flags with default values.\n- Add a flag to a command with `glint.flag`.\n- Add a `constraint.Constraint(a)` to a `glint.Flag(a)` with `glint.flag_constraint`\n\n#### Glint flag constraints: `constraint.Constraint(a)`\n\nConstraints are functions of shape `fn(a) -&gt; Result(a, snag.Snag)` that are executed after a flag value has been successfully parsed, all constraints applied to a flag must succeed for that flag to be successfully processed.\n\nConstraints can be any function so long as it satisfies the required type signature, and are useful for ensuring that data is correctly shaped **before** your glint commands are executed. This reduces unnecessary checks polluting the business logic of your commands.\n\nHere is an example of a constraint that guarantees a processed integer flag will be a positive number.\n\n_Note_ that constraints can both nicely be set up via pipes (`|&gt;`) or with `use`.\n\n```gleam\nimport glint\nimport snag\n// ...\n// with pipes\nglint.int_flag(&quot;my_int&quot;)\n|&gt; glint.flag_default(0)\n|&gt; glint.constraint(fn(i){\n  case i &lt; 0 {\n    True -&gt; snag.error(&quot;cannot be negative&quot;)\n    False -&gt; Ok(i)\n  }\n})\n// or\n// with use\nuse i &lt;- glint.flag_constraint(\n  glint.int_flag(&quot;my_int&quot;)\n  |&gt; glint.flag_default(0)\n)\ncase i &lt; 0 {\n  True -&gt; snag.error(&quot;cannot be negative&quot;)\n  False -&gt; Ok(i)\n}\n```\n\nThe `glint/constraint` module provides a few helpful utilities for applying constraints, namely\n\n- `constraint.one_of`: ensures that a value is one of some list of allowed values.\n- `constraint.none_of`: ensures that a value is not one of some list of disallowed values.\n- `constraint.each`: applies a constraint on individual items in a list of values (useful for applying constraints like `one_of` and `none_of` to lists.\n\nThe following example demonstrates how to constrain a `glint.Flag(List(Int))` to only allow the values 1, 2, 3 or 4 by combining `constraint.each` with `constraint.one_of`\n\n```gleam\nimport glint\nimport glint/constraint\nimport snag\n// ...\nglint.ints_flag(&quot;my_ints&quot;)\n|&gt; glint.flag_default([])\n|&gt; glint.flag_constraint(\n  [1, 2, 3, 4]\n  |&gt; constraint.one_of\n  |&gt; constraint.each\n)\n```\n\n## ✨ Complementary packages\n\nGlint works amazingly with these other packages:\n\n- [argv](https://github.com/lpil/argv), use this for cross-platform argument fetching\n- [gleescript](https://github.com/lpil/gleescript), use this to generate erlang escripts for your applications\n","url":"index.html"},{"doc":"glint/constraint","title":"Constraint","content":"pub type Constraint(a) =\n  fn(a) -&gt; snag.Result(a)\n Constraint type for verifying flag values\n\n\nSynonyms:\nglint/constraint.Constraint\nglint/constraint Constraint","url":"glint/constraint.html#Constraint"},{"doc":"glint/constraint","title":"each","content":"pub fn each(\n  constraint: fn(a) -&gt; Result(a, Snag),\n) -&gt; fn(List(a)) -&gt; Result(List(a), Snag)\n This is a convenience function for applying a Constraint(a) to a List(a).\n This is useful because the default behaviour for constraints on lists is that they will apply to the list as a whole.\n\n For example, to apply one_of to all items in a `List(Int)`:\n\n Via `use`:\n \n import glint\n import glint/constraint\n ...\n use li &lt;- glint.flag_constraint(glint.int_flag(&quot;my_flag&quot;))\n use i &lt;- constraint.each()\n i |&gt; one_of([1, 2, 3, 4])\n \n\n via a pipe:\n \n import glint\n import glint/constraint\n ...\n glint.int_flag(&quot;my_flag&quot;)\n |&gt; glint.flag_constraint(\n   constraint.one_of([1,2,3,4])\n   |&gt; constraint.each\n )\n \n\nSynonyms:\nglint/constraint.each\nglint/constraint each","url":"glint/constraint.html#each"},{"doc":"glint/constraint","title":"none_of","content":"pub fn none_of(disallowed: List(a)) -&gt; fn(a) -&gt; Result(a, Snag)\n Returns a Constraint that ensures the parsed flag value is not one of the disallowed values.\n\n \n import glint\n import glint/constraint\n ...\n glint.int_flag(&quot;my_flag&quot;)\n |&gt; glint.constraint(constraint.none_of([1, 2, 3, 4]))\n \n\nSynonyms:\nglint/constraint.none_of\nglint/constraint none_of","url":"glint/constraint.html#none_of"},{"doc":"glint/constraint","title":"one_of","content":"pub fn one_of(allowed: List(a)) -&gt; fn(a) -&gt; Result(a, Snag)\n Returns a Constraint that ensures the parsed flag value is one of the allowed values.\n\n \n import glint\n import glint/constraint\n ...\n glint.int_flag(&quot;my_flag&quot;)\n |&gt; glint.constraint(constraint.one_of([1, 2, 3, 4]))\n \n\nSynonyms:\nglint/constraint.one_of\nglint/constraint one_of","url":"glint/constraint.html#one_of"},{"doc":"glint/constraint","title":"glint/constraint","content":"","url":"glint/constraint.html"},{"doc":"glint","title":"ArgsCount","content":"pub type ArgsCount {\n  EqArgs(Int)\n  MinArgs(Int)\n}\n Specify the expected number of unnamed arguments with this type and the [`glint.unnamed_args`](#unnamed_args) function\n\nEqArgs(Int)\n Specifies that a command must accept a specific number of unnamed arguments\n\n\nMinArgs(Int)\n Specifies that a command must accept a minimum number of unnamed arguments\n\n\nSynonyms:\nglint.ArgsCount\nglint ArgsCount","url":"glint.html#ArgsCount"},{"doc":"glint","title":"Command","content":"pub opaque type Command(a)\n The type representing a glint command.\n\n To create a new command, use the [`glint.command`](#command) funcion.\n\n\nSynonyms:\nglint.Command\nglint Command","url":"glint.html#Command"},{"doc":"glint","title":"Flag","content":"pub opaque type Flag(a)\n Glint&#39;s typed flags.\n\n Flags can be created using any of:\n - [`glint.int_flag`](#int_flag)\n - [`glint.ints_flag`](#ints_flag)\n - [`glint.float_flag`](#float_flag)\n - [`glint.floats_flag`](#floats_flag)\n - [`glint.string_flag`](#string_flag)\n - [`glint.strings_flag`](#strings_flag)\n - [`glint.bool_flag`](#bool_flag)\n\n\nSynonyms:\nglint.Flag\nglint Flag","url":"glint.html#Flag"},{"doc":"glint","title":"Flags","content":"pub opaque type Flags\n Flags passed as input to a command.\n\n\nSynonyms:\nglint.Flags\nglint Flags","url":"glint.html#Flags"},{"doc":"glint","title":"Glint","content":"pub opaque type Glint(a)\n A container type for config and commands.\n\n This will be the main interaction point when setting up glint.\n To create a new one use [`glint.new`](#new).\n\n\nSynonyms:\nglint.Glint\nglint Glint","url":"glint.html#Glint"},{"doc":"glint","title":"NamedArgs","content":"pub opaque type NamedArgs\n A container for named arguments available to commands at runtime.\n\n\nSynonyms:\nglint.NamedArgs\nglint NamedArgs","url":"glint.html#NamedArgs"},{"doc":"glint","title":"PrettyHelp","content":"pub type PrettyHelp {\n  PrettyHelp(usage: Colour, flags: Colour, subcommands: Colour)\n}\n PrettyHelp defines the header colours to be used when styling help text\n\nPrettyHelp(usage: Colour, flags: Colour, subcommands: Colour)\n\n\nSynonyms:\nglint.PrettyHelp\nglint PrettyHelp","url":"glint.html#PrettyHelp"},{"doc":"glint","title":"Runner","content":"pub type Runner(a) =\n  fn(NamedArgs, List(String), Flags) -&gt; a\n Functions that execute when glint commands are run.\n\n\nSynonyms:\nglint.Runner\nglint Runner","url":"glint.html#Runner"},{"doc":"glint","title":"add","content":"pub fn add(\n  to glint: Glint(a),\n  at path: List(String),\n  do command: Command(a),\n) -&gt; Glint(a)\n Adds a new command to be run at the specified path.\n\n If the path is `[]`, the root command is set with the provided function and\n flags.\n\n Note: all command paths are sanitized by stripping whitespace and removing any empty string elements.\n\n \n glint.new()\n |&gt; glint.add(at: [], do: root_command())\n |&gt; glint.add(at: [&quot;subcommand&quot;], do: subcommand())\n ...\n \n\nSynonyms:\nglint.add\nglint add","url":"glint.html#add"},{"doc":"glint","title":"as_module","content":"pub fn as_module(glint: Glint(a)) -&gt; Glint(a)\n Adjust the generated help text to reflect that the current glint app should be run as a gleam module.\n\n Use in conjunction with [`glint.with_name`](#with_name) to get usage text output like `gleam run -m &lt;name&gt;`\n\nSynonyms:\nglint.as_module\nglint as_module","url":"glint.html#as_module"},{"doc":"glint","title":"bool_flag","content":"pub fn bool_flag(named name: String) -&gt; Flag(Bool)\n Initialise a boolean flag.\n\nSynonyms:\nglint.bool_flag\nglint bool_flag","url":"glint.html#bool_flag"},{"doc":"glint","title":"command","content":"pub fn command(\n  do runner: fn(NamedArgs, List(String), Flags) -&gt; a,\n) -&gt; Command(a)\n Create a [Command(a)](#Command) from a [Runner(a)](#Runner).\n\n ### Example:\n\n \n use &lt;- glint.command_help(&quot;Some awesome help text&quot;)\n use named_arg &lt;- glint.named_arg(&quot;some_arg&quot;)\n use &lt;- glint.unnamed_args(glint.EqArgs(0))\n ...\n use named, unnamed, flags &lt;- glint.command()\n let my_arg = named_arg(named)\n ...\n \nSynonyms:\nglint.command\nglint command","url":"glint.html#command"},{"doc":"glint","title":"command_help","content":"pub fn command_help(\n  of desc: String,\n  with f: fn() -&gt; Command(a),\n) -&gt; Command(a)\n Attach a helptext description to a [`Command(a)`](#Command)\n\n This function allows for user-supplied newlines in long text strings. Individual newline characters are instead converted to spaces.\n This is useful for developers to format their help text in a more readable way in the source code.\n\n For formatted text to appear on a new line, use 2 newline characters.\n For formatted text to appear in a new paragraph, use 3 newline characters.\n\nSynonyms:\nglint.command_help\nglint command_help","url":"glint.html#command_help"},{"doc":"glint","title":"default_pretty_help","content":"pub fn default_pretty_help() -&gt; PrettyHelp\n Default colouring for help text.\n\n mint (r: 182, g: 255, b: 234) colour for usage\n\n pink (r: 255, g: 175, b: 243) colour for flags\n\n buttercup (r: 252, g: 226, b: 174) colour for subcommands\n\nSynonyms:\nglint.default_pretty_help\nglint default_pretty_help","url":"glint.html#default_pretty_help"},{"doc":"glint","title":"flag","content":"pub fn flag(\n  of flag: Flag(a),\n  with f: fn(fn(Flags) -&gt; Result(a, Snag)) -&gt; Command(b),\n) -&gt; Command(b)\n Add a [`Flag(a)`](#Flag) to a [`Command(a)`](#Command)\n\n The provided callback is provided a function to fetch the current flag fvalue from the command input [`Flags`](#Flags).\n\n This function is most ergonomic as part of a `use` chain when building commands.\n\n ### Example:\n\n \n ...\n use repeat &lt;- glint.flag(\n   glint.int_flag(&quot;repeat&quot;)\n   |&gt; glint.flag_default(1)\n   |&gt; glint.flag_help(&quot;Repeat the message n-times&quot;)\n )\n ...\n use named, unnamed, flags &lt;- glint.command()\n let repeat_value = repeat(flags)\n \n\nSynonyms:\nglint.flag\nglint flag","url":"glint.html#flag"},{"doc":"glint","title":"flag_constraint","content":"pub fn flag_constraint(\n  builder: Flag(a),\n  constraint: fn(a) -&gt; Result(a, Snag),\n) -&gt; Flag(a)\n Attach a constraint to a flag.\n\n As constraints are just functions, this works well as both part of a pipeline or with `use`.\n\n\n ### Pipe:\n\n \n glint.int_flag(&quot;my_flag&quot;)\n |&gt; glint.flag_help(&quot;An awesome flag&quot;)\n |&gt; glint.flag_constraint(fn(i) {\n   case i &lt; 0 {\n     True -&gt; snag.error(&quot;must be greater than 0&quot;)\n     False -&gt; Ok(i)\n   }})\n \n\n ### Use:\n\n \n use i &lt;- glint.flag_constraint(\n   glint.int_flag(&quot;my_flag&quot;)\n   |&gt; glint.flag_help(&quot;An awesome flag&quot;)\n )\n case i &lt; 0 {\n   True -&gt; snag.error(&quot;must be greater than 0&quot;)\n   False -&gt; Ok(i)\n }\n \n\nSynonyms:\nglint.flag_constraint\nglint flag_constraint","url":"glint.html#flag_constraint"},{"doc":"glint","title":"flag_default","content":"pub fn flag_default(for flag: Flag(a), of default: a) -&gt; Flag(a)\n Set the default value for a flag.\n\n ### Example:\n\n \n glint.int_flag(&quot;awesome_flag&quot;)\n |&gt; glint.flag_default(1)\n \n\nSynonyms:\nglint.flag_default\nglint flag_default","url":"glint.html#flag_default"},{"doc":"glint","title":"flag_help","content":"pub fn flag_help(\n  for flag: Flag(a),\n  of description: String,\n) -&gt; Flag(a)\n Attach a help text description to a flag.\n\n This function allows for user-supplied newlines in long text strings. Individual newline characters are instead converted to spaces.\n This is useful for developers to format their help text in a more readable way in the source code.\n\n For formatted text to appear on a new line, use 2 newline characters.\n For formatted text to appear in a new paragraph, use 3 newline characters.\n\n ### Example:\n\n \n glint.int_flag(&quot;awesome_flag&quot;)\n |&gt; glint.flag_help(&quot;Some great text!&quot;)\n \n\nSynonyms:\nglint.flag_help\nglint flag_help","url":"glint.html#flag_help"},{"doc":"glint","title":"float_flag","content":"pub fn float_flag(named name: String) -&gt; Flag(Float)\nInitialise a float flag.\n\nSynonyms:\nglint.float_flag\nglint float_flag","url":"glint.html#float_flag"},{"doc":"glint","title":"floats_flag","content":"pub fn floats_flag(named name: String) -&gt; Flag(List(Float))\n Initialise a float list flag.\n\nSynonyms:\nglint.floats_flag\nglint floats_flag","url":"glint.html#floats_flag"},{"doc":"glint","title":"get_flag","content":"pub fn get_flag(\n  from flags: Flags,\n  for flag: Flag(a),\n) -&gt; Result(a, Snag)\n Gets the value for the associated flag.\n\n This function should only ever be used when fetching flags set at the group level.\n For local flags please use the getter functions provided when calling [`glint.flag`](#flag).\n\nSynonyms:\nglint.get_flag\nglint get_flag","url":"glint.html#get_flag"},{"doc":"glint","title":"global_help","content":"pub fn global_help(\n  in glint: Glint(a),\n  of description: String,\n) -&gt; Glint(a)\n Set help text for the application as a whole.\n\n Help text set with this function wil be printed at the top of the help text for every command.\n To set help text specifically for the root command please use [`glint.command_help`](#command_help) or [`glint.path_help([],...)`](#path_help)\n\n This function allows for user-supplied newlines in long text strings. Individual newline characters are instead converted to spaces.\n This is useful for developers to format their help text in a more readable way in the source code.\n\n For formatted text to appear on a new line, use 2 newline characters.\n For formatted text to appear in a new paragraph, use 3 newline characters.\n\nSynonyms:\nglint.global_help\nglint global_help","url":"glint.html#global_help"},{"doc":"glint","title":"group_flag","content":"pub fn group_flag(\n  in glint: Glint(a),\n  at path: List(String),\n  of flag: Flag(b),\n) -&gt; Glint(a)\n Add a flag for a group of commands.\n The provided flags will be available to all commands at or beyond the provided path\n\nSynonyms:\nglint.group_flag\nglint group_flag","url":"glint.html#group_flag"},{"doc":"glint","title":"int_flag","content":"pub fn int_flag(named name: String) -&gt; Flag(Int)\n Initialise an int flag.\n\nSynonyms:\nglint.int_flag\nglint int_flag","url":"glint.html#int_flag"},{"doc":"glint","title":"ints_flag","content":"pub fn ints_flag(named name: String) -&gt; Flag(List(Int))\n Initialise an int list flag.\n\nSynonyms:\nglint.ints_flag\nglint ints_flag","url":"glint.html#ints_flag"},{"doc":"glint","title":"named_arg","content":"pub fn named_arg(\n  named name: String,\n  with f: fn(fn(NamedArgs) -&gt; String) -&gt; Command(a),\n) -&gt; Command(a)\n Add a list of named arguments to a [`Command(a)`](#Command). The value can be retrieved from the command&#39;s [`NamedArgs`](#NamedArgs)\n\n These named arguments will be matched with the first N arguments passed to the command.\n\n\n **IMPORTANT**:\n\n - Matched named arguments will **not** be present in the commmand&#39;s unnamed args list\n\n - All named arguments must match for a command to succeed.\n\n ### Example:\n\n \n ...\n use first_name &lt;- glint.named_arg(&quot;first name&quot;)\n ...\n use named, unnamed, flags &lt;- glint.command()\n let first = first_name(named)\n \n\nSynonyms:\nglint.named_arg\nglint named_arg","url":"glint.html#named_arg"},{"doc":"glint","title":"new","content":"pub fn new() -&gt; Glint(a)\n Create a new glint instance.\n\nSynonyms:\nglint.new\nglint new","url":"glint.html#new"},{"doc":"glint","title":"path_help","content":"pub fn path_help(\n  in glint: Glint(a),\n  at path: List(String),\n  put description: String,\n) -&gt; Glint(a)\n Set the help text for a specific command path.\n\n This function is intended to allow users to set the help text of commands that might not be directly instantiated,\n such as commands with no business logic associated to them but that have subcommands.\n\n Using this function should almost never be necessary, in most cases you should use [`glint.command_help`](#command_help) insstead.\nSynonyms:\nglint.path_help\nglint path_help","url":"glint.html#path_help"},{"doc":"glint","title":"pretty_help","content":"pub fn pretty_help(\n  glint: Glint(a),\n  pretty: PrettyHelp,\n) -&gt; Glint(a)\n Enable custom colours for help text headers.\n\n For a pre-made style, pass in [`glint.default_pretty_help`](#default_pretty_help)\n\nSynonyms:\nglint.pretty_help\nglint pretty_help","url":"glint.html#pretty_help"},{"doc":"glint","title":"run","content":"pub fn run(from glint: Glint(a), for args: List(String)) -&gt; Nil\n Run a glint app and print any errors enountered, or the help text if requested.\n This function ignores any value returned by the command that was run.\n If you would like to do handle the command output please see the [`glint.run_and_handle`](#run_and_handle) function.\n\n IMPORTANT: This function exits with code 1 if an error was encountered.\n If this behaviour is not desired please disable it with [`glint.without_exit`](#without_exit)\n\nSynonyms:\nglint.run\nglint run","url":"glint.html#run"},{"doc":"glint","title":"run_and_handle","content":"pub fn run_and_handle(\n  from glint: Glint(a),\n  for args: List(String),\n  with handle: fn(a) -&gt; b,\n) -&gt; Nil\n Run a glint app with a custom handler for command output.\n This function prints any errors enountered or the help text if requested.\n\n IMPORTANT: This function exits with code 1 if an error was encountered.\n If this behaviour is not desired please disable it with [`glint.without_exit`](#without_exit)\n\nSynonyms:\nglint.run_and_handle\nglint run_and_handle","url":"glint.html#run_and_handle"},{"doc":"glint","title":"string_flag","content":"pub fn string_flag(named name: String) -&gt; Flag(String)\n Initialise a string flag.\n\nSynonyms:\nglint.string_flag\nglint string_flag","url":"glint.html#string_flag"},{"doc":"glint","title":"strings_flag","content":"pub fn strings_flag(named name: String) -&gt; Flag(List(String))\n Intitialise a string list flag.\n\nSynonyms:\nglint.strings_flag\nglint strings_flag","url":"glint.html#strings_flag"},{"doc":"glint","title":"unnamed_args","content":"pub fn unnamed_args(\n  of count: ArgsCount,\n  with f: fn() -&gt; Command(a),\n) -&gt; Command(a)\n Specify a specific number of unnamed args that a given command expects.\n\n Use in conjunction with [`glint.ArgsCount`](#ArgsCount) to specify either a minimum or a specific number of args.\n\n ### Example:\n\n \n ...\n // for a command that accets only 1 unnamed argument:\n use &lt;- glint.unnamed_args(glint.EqArgs(1))\n ...\n named, unnamed, flags &lt;- glint.command()\n let assert Ok([arg]) = unnamed\n \n\nSynonyms:\nglint.unnamed_args\nglint unnamed_args","url":"glint.html#unnamed_args"},{"doc":"glint","title":"with_column_gap","content":"pub fn with_column_gap(glint: Glint(a), gap: Int) -&gt; Glint(a)\n Adjusts the size of the gap between columns in the help output.\n\n Default: 2.\n\nSynonyms:\nglint.with_column_gap\nglint with_column_gap","url":"glint.html#with_column_gap"},{"doc":"glint","title":"with_indent_width","content":"pub fn with_indent_width(glint: Glint(a), width: Int) -&gt; Glint(a)\n Adjusts the indent width used to indent content under the usage, flags,\n and subcommands headings in the help output.\n\n Default: 4.\n\nSynonyms:\nglint.with_indent_width\nglint with_indent_width","url":"glint.html#with_indent_width"},{"doc":"glint","title":"with_max_output_width","content":"pub fn with_max_output_width(\n  glint: Glint(a),\n  width: Int,\n) -&gt; Glint(a)\n Adjusts the output width at which help text will wrap onto a new line.\n\n Default: 80.\n\nSynonyms:\nglint.with_max_output_width\nglint with_max_output_width","url":"glint.html#with_max_output_width"},{"doc":"glint","title":"with_min_first_column_width","content":"pub fn with_min_first_column_width(\n  glint: Glint(a),\n  width: Int,\n) -&gt; Glint(a)\n Adjusts the minimum width of the column containing flag and command names in the help output.\n\n Default: 20.\n\nSynonyms:\nglint.with_min_first_column_width\nglint with_min_first_column_width","url":"glint.html#with_min_first_column_width"},{"doc":"glint","title":"with_name","content":"pub fn with_name(glint: Glint(a), name: String) -&gt; Glint(a)\n Give the current glint application a name.\n\n The name specified here is used when generating help text for the current glint instance.\n\nSynonyms:\nglint.with_name\nglint with_name","url":"glint.html#with_name"},{"doc":"glint","title":"without_exit","content":"pub fn without_exit(glint: Glint(a)) -&gt; Glint(a)\n By default, Glint exits with error status 1 when an error is encountered (eg. invalid flag or command not found)\n\n Calling this function disables that feature.\n\nSynonyms:\nglint.without_exit\nglint without_exit","url":"glint.html#without_exit"},{"doc":"glint","title":"glint","content":"","url":"glint.html"}]);